@@ -1,7 +1,7 @@
 import inspect
 import warnings
 
-from apps.api_auth import get_user_model
+from .import get_user_model
 from django.contrib.auth.backends import BaseBackend
 from django.db.models import Exists, OuterRef, Q
 from .models import AuthUser
