@@ -1,5 +1,5 @@
 from rest_framework.decorators import action
-from project.utils.viewsets import CustomModelViewSet, TreeAPIView
+from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, TreeAPIView
 from rest_framework.response import Response
 
 from .models import Category
