@@ -1,5 +1,5 @@
-from project.utils.oss import OSS
-from project.utils.wechat import mini_program, official_account
+from bluedot_rest_framework.utils.oss import OSS
+from bluedot_rest_framework.utils.wechat import mini_program, official_account
 
 
 class CreateQrcode:
