@@ -44,6 +44,17 @@ class CustomModelViewSet(ModelViewSet):
                             lookup_type = i + '__exists'
                             queryset = queryset.filter(
                                 **{lookup_type: True})
+                    elif key == 'time_state':
+                        date_now = datetime.now()
+                        if field_value == 'underway':
+                            queryset = queryset.filter(
+                                **{f"{self.filterset_fields[key]['start_time']}__lt": date_now, f"{self.filterset_fields[key]['end_time']}__gt": date_now})
+                        elif field_value == 'notstarted':
+                            queryset = queryset.filter(
+                                **{f"{self.filterset_fields[key]['end_time']}__lt": date_now})
+                        elif field_value == 'finished':
+                            queryset = queryset.filter(
+                                **{f"{self.filterset_fields[key]['start_time']}__gt": date_now})
 
                     else:
                         _filter = self.filterset_fields[key]
